# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ....model import Adapter
from ....settings import ISettings


class BaseQHeaderViewISettingsAdapter(Adapter):
    """ A base adapter to implement ISettings for a widget that has an
    embedded QHeaderView.
    """

    @ISettings.id.getter
    def id(self):
        """ Invoked to get the identifier. """

        return self.adaptee.objectName()

    def restore(self, settings_manager):
        """ Restore the settings obtained from a settings manager.

        :param settings_manager:
            is the settings manager.
        """

        value = settings_manager.read_value('header')
        if value is not None:
            self.adaptee.header().restoreState(value)

    def save(self, settings_manager):
        """ Save the settings to a settings manager.

        :param settings_manager:
            is the settings manager.
        """

        settings_manager.write_value('header',
                self.adaptee.header().saveState())
